from terminalpackagehamderber.src import terminal_settings as settings, command_handler


def start():
    command_handler.run_command("Clrscrn")
    settings.apply_settings()


def main():
    start()
    while True:
        # Main program loop. Constantly tries to get commands from the user, displaying the username
        # that is being used to connect to the MySQL database. Ex: command line showing 'admin>'
        command_handler.get_user_input(f"admin> ")


if __name__ == "__main__":
    # Runs main but only if IDE 'run' is performed from this file
    main()





launch_announcement = "Running KevTerminal!\n"


def apply_settings():
    # webscraper.clone_data_into_csv = settings_dict['clone_data_into_csv']
    # mysqlinteractor.rebuild_database = settings_dict['rebuild_sql_database']
    print(f"{launch_announcement}")


settings_dict = {'stats_dec_places': 2,
                 'clone_data_into_csv': True,
                 'rebuild_sql_database': False}
